## ----setup, message = FALSE---------------------------------------------------
library(gemma.R)
library(dplyr)
library(pheatmap)

## ----include = FALSE----------------------------------------------------------
options('gemma.memoised' = TRUE)

## -----------------------------------------------------------------------------
get_dataset_annotations('GSE18728') %>%
    gemma_kable

## -----------------------------------------------------------------------------
samples <- get_dataset_samples('GSE18728')
samples$sample.factorValues[[1]] %>% 
    gemma_kable()

## -----------------------------------------------------------------------------
id <- samples$sample.factorValues[[1]] %>% 
    filter(value == 'resistant to') %>% {.$ID} %>% unique

# count how many patients has this phenotype
samples$sample.factorValues %>% sapply(\(x){
    id %in% x$ID
}) %>% sum


## -----------------------------------------------------------------------------
id <- samples$sample.factorValues[[1]] %>% 
    filter(value == 'resistant to') %>% {.$factor.ID} %>% unique

samples$sample.factorValues %>% lapply(\(x){
    x %>% filter(factor.ID == id) %>% {.$summary}
}) %>% unlist %>% unique

## -----------------------------------------------------------------------------
design <- make_design(samples)
design[,-1] %>% head %>%  # first column is just a copy of the original factor values
    gemma_kable()

## -----------------------------------------------------------------------------
design %>%
    group_by(treatment,phenotype,`collection of material`) %>% 
    summarize(n= n()) %>% 
    arrange(desc(n)) %>% 
    gemma_kable()


## -----------------------------------------------------------------------------
# removing columns containing factor values and URIs for brevity
remove_columns <- c('baseline.factors','experimental.factors','subsetFactor','factor.category.URI')

dea <- get_dataset_differential_expression_analyses("GSE18728")

dea[,.SD,.SDcols = !remove_columns] %>% 
    gemma_kable()

## -----------------------------------------------------------------------------
contrast <- dea[1,]

## -----------------------------------------------------------------------------
# removing URIs for brevity
uri_columns = c('category.URI',
                'object.URI',
                'value.URI',
                'predicate.URI',
                'factor.category.URI')

contrast$baseline.factors[[1]][,.SD,.SDcols = !uri_columns] %>% 
     gemma_kable()

contrast$experimental.factors[[1]][,.SD,.SDcols = !uri_columns] %>% 
     gemma_kable()

## -----------------------------------------------------------------------------
contrast <- dea[2,]

## -----------------------------------------------------------------------------
contrast$baseline.factors[[1]][,.SD,.SDcols = !uri_columns] %>% 
     gemma_kable()

contrast$experimental.factors[[1]][,.SD,.SDcols = !uri_columns] %>% 
     gemma_kable()

## -----------------------------------------------------------------------------
contrast$subsetFactor[[1]][,.SD,.SDcols = !uri_columns] %>%
     gemma_kable()

## -----------------------------------------------------------------------------
obj <-  get_dataset_object("GSE18728",resultSets = contrast$result.ID,contrasts = contrast$contrast.ID,type = 'list')
obj[[1]]$design[,-1] %>% 
    head %>% gemma_kable()

## -----------------------------------------------------------------------------
dif_vals <- get_differential_expression_values('GSE18728')
dif_vals[[as.character(contrast$result.ID)]] %>% head %>%  
     gemma_kable()

## -----------------------------------------------------------------------------
# getting the top 10 genes
top_genes <- dif_vals[[as.character(contrast$result.ID)]] %>% 
    arrange(across(paste0('contrast_',contrast$contrast.ID,'_pvalue'))) %>% 
    filter(GeneSymbol!='' | grepl("|",GeneSymbol,fixed = TRUE)) %>% # remove blank genes or probes with multiple genes
    {.[1:10,]}
top_genes %>% select(Probe,NCBIid,GeneSymbol) %>% 
     gemma_kable()

## -----------------------------------------------------------------------------
exp_subset<- obj[[1]]$exp %>% 
    filter(Probe %in% top_genes$Probe)
genes <- top_genes$GeneSymbol

# ordering design file
design <- obj[[1]]$design %>% arrange(treatment,phenotype)

# shorten the resistance label a bit
design$phenotype[design$phenotype == "resistant to toward capecitabine, resistant to toward docetaxel trihydrate"] = "drug resistant"

exp_subset[,.SD,.SDcols = rownames(design)] %>% t  %>% scale %>% t %>%
    pheatmap(cluster_rows = FALSE,cluster_cols = FALSE,labels_row = genes,
             annotation_col =design %>% select(phenotype,treatment))


## ----sessionInfo, echo=FALSE--------------------------------------------------
sessionInfo()

